==> haskell-lexer-1.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lexer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-lexer
version:              1.1
visibility:           public
id:                   haskell-lexer-1.1-HG6gtTOigcKECn3uPbgseB
key:                  haskell-lexer-1.1-HG6gtTOigcKECn3uPbgseB
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Thomas Hallgren
homepage:             https://github.com/yav/haskell-lexer
synopsis:             A fully compliant Haskell 98 lexer.
description:          A fully compliant Haskell 98 lexer.
category:             Language
abi:                  71a1ee3b1bfb8a9f75b35b0c5d26d55f
exposed:              True
exposed-modules:      Language.Haskell.Lexer
hidden-modules:
    Language.Haskell.Lexer.Layout Language.Haskell.Lexer.Tokens
    Language.Haskell.Lexer.Lex Language.Haskell.Lexer.Utils
    Language.Haskell.Lexer.Position

import-dirs:          /usr/lib/ghc-8.10.4/site-local/haskell-lexer-1.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/haskell-lexer-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/haskell-lexer-1.1
hs-libraries:         HShaskell-lexer-1.1-HG6gtTOigcKECn3uPbgseB
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-lexer/html/haskell-lexer.haddock
haddock-html:         /usr/share/doc/haskell-lexer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lexer-1.1-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lexer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-lexer
version:              1.1
visibility:           public
id:                   haskell-lexer-1.1-7oPlfVo8NPkJMo7wLz4t6q
key:                  haskell-lexer-1.1-7oPlfVo8NPkJMo7wLz4t6q
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Thomas Hallgren
homepage:             https://github.com/yav/haskell-lexer
synopsis:             A fully compliant Haskell 98 lexer.
description:          A fully compliant Haskell 98 lexer.
category:             Language
abi:                  1d54f062ac8758295bb4aac1d71ae0b7
exposed:              True
exposed-modules:      Language.Haskell.Lexer
hidden-modules:
    Language.Haskell.Lexer.Layout Language.Haskell.Lexer.Tokens
    Language.Haskell.Lexer.Lex Language.Haskell.Lexer.Utils
    Language.Haskell.Lexer.Position

import-dirs:          /usr/lib/ghc-8.10.5/site-local/haskell-lexer-1.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/haskell-lexer-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/haskell-lexer-1.1
hs-libraries:         HShaskell-lexer-1.1-7oPlfVo8NPkJMo7wLz4t6q
depends:              base-4.14.2.0
haddock-interfaces:   /usr/share/doc/haskell-lexer/html/haskell-lexer.haddock
haddock-html:         /usr/share/doc/haskell-lexer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
